@@ -27,6 +27,7 @@ from oslo_config import cfg
 from oslo_db import options as db_options
 from oslo_log import log as logging
 import oslo_messaging as messaging
+from oslo_policy import opts as policy_opts
 
 from octavia.certificates.common import local
 from octavia.common import constants
@@ -105,6 +106,9 @@ api_opts = [
     cfg.BoolOpt('healthcheck_enabled', default=False,
                 help=_("When True, the oslo middleware healthcheck endpoint "
                        "is enabled in the Octavia API.")),
+    cfg.IntOpt('healthcheck_refresh_interval', default=5,
+               help=_("The interval healthcheck plugins should cache results, "
+                      "in seconds.")),
     cfg.StrOpt('default_listener_ciphers',
                default=constants.CIPHERS_OWASP_SUITE_B,
                help=_("Default OpenSSL cipher string (colon-separated) for "
@@ -130,10 +134,17 @@ api_opts = [
                choices=constants.TLS_ALL_VERSIONS + [None],
                help=_('Minimum allowed TLS version for listeners and pools.')),
     cfg.ListOpt('default_listener_alpn_protocols',
-                default=[lib_consts.ALPN_PROTOCOL_HTTP_1_1,
+                default=[lib_consts.ALPN_PROTOCOL_HTTP_2,
+                         lib_consts.ALPN_PROTOCOL_HTTP_1_1,
                          lib_consts.ALPN_PROTOCOL_HTTP_1_0],
                 help=_('List of ALPN protocols to use for new TLS-enabled '
                        'listeners.')),
+    cfg.ListOpt('default_pool_alpn_protocols',
+                default=[lib_consts.ALPN_PROTOCOL_HTTP_2,
+                         lib_consts.ALPN_PROTOCOL_HTTP_1_1,
+                         lib_consts.ALPN_PROTOCOL_HTTP_1_0],
+                help=_('List of ALPN protocols to use for new TLS-enabled '
+                       'pools.')),
 ]
 
 # Options only used by the amphora agent
@@ -205,7 +216,11 @@ amphora_agent_opts = [
     cfg.StrOpt('amphora_id', help=_("The amphora ID.")),
     cfg.StrOpt('amphora_udp_driver',
                default='keepalived_lvs',
-               help='The UDP API backend for amphora agent.'),
+               help='The UDP API backend for amphora agent.',
+               deprecated_for_removal=True,
+               deprecated_reason=_('amphora-agent will not support any other '
+                                   'backend than keepalived_lvs.'),
+               deprecated_since='Wallaby'),
 ]
 
 compute_opts = [
@@ -968,3 +983,19 @@ def setup_remote_debugger():
                       {'debug-host': debugger_host,
                        'debug-port': debugger_port})
         raise
+
+
+def set_lib_defaults():
+    """Update default value for configuration options from other namespace.
+
+    Example, oslo lib config options. This is needed for
+    config generator tool to pick these default value changes.
+    https://docs.openstack.org/oslo.config/latest/cli/
+    generator.html#modifying-defaults-from-other-namespaces
+    """
+
+    # TODO(gmann): Remove setting the default value of config policy_file
+    # once oslo_policy change the default value to 'policy.yaml'.
+    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+    # Update default value of oslo.policy policy_file config option.
+    policy_opts.set_defaults(cfg.CONF, 'policy.yaml')
