@@ -232,8 +232,8 @@ DEFAULT_MAX_RETRIES_DOWN = 3
 MIN_HM_RETRIES = 1
 MAX_HM_RETRIES = 10
 
-# 24 days:   days  d    h    m    ms
-MAX_TIMEOUT = 24 * 24 * 60 * 60 * 1000
+# 1 year:     y     d    h    m    ms
+MAX_TIMEOUT = 365 * 24 * 60 * 60 * 1000
 MIN_TIMEOUT = 0
 
 DEFAULT_TIMEOUT_CLIENT_DATA = 50000
@@ -731,6 +731,7 @@ DEFAULT_PAGE_SIZE = 1000
 
 # RBAC
 LOADBALANCER_API = 'os_load-balancer_api'
+
 RULE_API_ADMIN = 'rule:load-balancer:admin'
 RULE_API_READ = 'rule:load-balancer:read'
 RULE_API_READ_GLOBAL = 'rule:load-balancer:read-global'
@@ -738,6 +739,7 @@ RULE_API_WRITE = 'rule:load-balancer:write'
 RULE_API_READ_QUOTA = 'rule:load-balancer:read-quota'
 RULE_API_READ_QUOTA_GLOBAL = 'rule:load-balancer:read-quota-global'
 RULE_API_WRITE_QUOTA = 'rule:load-balancer:write-quota'
+
 RBAC_LOADBALANCER = '{}:loadbalancer:'.format(LOADBALANCER_API)
 RBAC_LISTENER = '{}:listener:'.format(LOADBALANCER_API)
 RBAC_POOL = '{}:pool:'.format(LOADBALANCER_API)
@@ -756,6 +758,7 @@ RBAC_FLAVOR_PROFILE = '{}:flavor-profile:'.format(LOADBALANCER_API)
 RBAC_AVAILABILITY_ZONE = '{}:availability-zone:'.format(LOADBALANCER_API)
 RBAC_AVAILABILITY_ZONE_PROFILE = '{}:availability-zone-profile:'.format(
     LOADBALANCER_API)
+
 RBAC_POST = 'post'
 RBAC_PUT = 'put'
 RBAC_PUT_CONFIG = 'put_config'
@@ -768,6 +771,16 @@ RBAC_GET_DEFAULTS = 'get_defaults'
 RBAC_GET_STATS = 'get_stats'
 RBAC_GET_STATUS = 'get_status'
 
+RBAC_SCOPE_PROJECT = 'project'
+RBAC_SCOPE_SYSTEM = 'system'
+
+RBAC_ROLES_DEPRECATED_REASON = (
+    'The Octavia API now requires the OpenStack default roles and scoped '
+    'tokens. '
+    'See https://docs.openstack.org/octavia/latest/configuration/policy.html '
+    'and https://docs.openstack.org/keystone/latest/contributor/'
+    'services.html#reusable-default-roles for more information.')
+
 # PROVIDERS
 OCTAVIA = 'octavia'
 AMPHORAV2 = 'amphorav2'
@@ -781,6 +794,7 @@ AMP_NETNS_SVC_PREFIX = 'amphora-netns'
 
 # Amphora Feature Compatibility
 HTTP_REUSE = 'has_http_reuse'
+POOL_ALPN = 'has_pool_alpn'
 
 # TODO(johnsom) convert these to octavia_lib constants
 # once octavia is transitioned to use octavia_lib
@@ -807,6 +821,12 @@ TOPIC_AMPHORA_V2 = 'octavia_provisioning_v2'
 HAPROXY_HTTP_PROTOCOLS = [lib_consts.PROTOCOL_HTTP,
                           lib_consts.PROTOCOL_TERMINATED_HTTPS]
 
+LVS_PROTOCOLS = [PROTOCOL_UDP,
+                 lib_consts.PROTOCOL_SCTP]
+
+HAPROXY_BACKEND = 'HAPROXY'
+LVS_BACKEND = 'LVS'
+
 # Map each supported protocol to its L4 protocol
 L4_PROTOCOL_MAP = {
     PROTOCOL_TCP: PROTOCOL_TCP,
