@@ -172,7 +172,7 @@ class ControllerWorker(object):
         if not db_health_monitor:
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'healthmonitor',
-                        db_health_monitor[constants.HEALTHMONITOR_ID])
+                        health_monitor[constants.HEALTHMONITOR_ID])
             raise db_exceptions.NoResultFound
 
         pool = db_health_monitor.pool
@@ -449,15 +449,8 @@ class ControllerWorker(object):
         :returns: None
         :raises NoSuitablePool: Unable to find the node pool
         """
-        db_member = self._member_repo.get(db_apis.get_session(),
-                                          id=member[constants.MEMBER_ID])
-        if not db_member:
-            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
-                        '60 seconds.', 'l7member',
-                        member[constants.MEMBER_ID])
-            raise db_exceptions.NoResultFound
-
-        pool = db_member.pool
+        pool = self._pool_repo.get(db_apis.get_session(),
+                                   id=member[constants.POOL_ID])
         load_balancer = pool.load_balancer
         provider_lb = provider_utils.db_loadbalancer_to_provider_loadbalancer(
             load_balancer).to_dict()
@@ -723,15 +716,8 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_l7policy = self._l7policy_repo.get(
-            db_apis.get_session(), id=l7policy[constants.L7POLICY_ID])
-        if not db_l7policy:
-            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
-                        '60 seconds.', 'l7policy',
-                        l7policy[constants.L7POLICY_ID])
-            raise db_exceptions.NoResultFound
-
-        db_listener = db_l7policy.listener
+        db_listener = self._listener_repo.get(
+            db_apis.get_session(), id=l7policy[constants.LISTENER_ID])
 
         listeners_dicts = (
             provider_utils.db_listeners_to_provider_dicts_list_of_dicts(
@@ -804,15 +790,8 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_l7rule = self._l7rule_repo.get(db_apis.get_session(),
-                                          id=l7rule[constants.L7RULE_ID])
-        if not db_l7rule:
-            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
-                        '60 seconds.', 'l7rule',
-                        l7rule[constants.L7RULE_ID])
-            raise db_exceptions.NoResultFound
-
-        db_l7policy = db_l7rule.l7policy
+        db_l7policy = self._l7policy_repo.get(db_apis.get_session(),
+                                              id=l7rule[constants.L7POLICY_ID])
 
         load_balancer = db_l7policy.listener.load_balancer
 
@@ -886,13 +865,14 @@ class ControllerWorker(object):
             flow_utils.get_update_l7rule_flow,
             store=store)
 
-    def failover_amphora(self, amphora_id):
+    def failover_amphora(self, amphora_id, reraise=False):
         """Perform failover operations for an amphora.
 
         Note: This expects the load balancer to already be in
         provisioning_status=PENDING_UPDATE state.
 
         :param amphora_id: ID for amphora to failover
+        :param reraise: If enabled reraise any caught exception
         :returns: None
         :raises octavia.common.exceptions.NotFound: The referenced amphora was
                                                     not found
@@ -968,7 +948,7 @@ class ControllerWorker(object):
                              constants.VIP: vip_dict,
                              constants.AMPHORA_ID: amphora_id}
 
-            self.services_controller.run_poster(
+            self.run_flow(
                 flow_utils.get_failover_amphora_flow,
                 amphora.to_dict(), lb_amp_count,
                 store=stored_params, wait=True)
@@ -981,7 +961,7 @@ class ControllerWorker(object):
                       "role": amphora.role})
 
         except Exception as e:
-            with excutils.save_and_reraise_exception(reraise=False):
+            with excutils.save_and_reraise_exception(reraise=reraise):
                 LOG.exception("Amphora %s failover exception: %s",
                               amphora_id, str(e))
                 self._amphora_repo.update(db_apis.get_session(),
@@ -1120,7 +1100,7 @@ class ControllerWorker(object):
             else:
                 stored_params[constants.AVAILABILITY_ZONE] = {}
 
-            self.services_controller.run_poster(
+            self.run_flow(
                 flow_utils.get_failover_LB_flow, amps, provider_lb_dict,
                 store=stored_params, wait=True)
 
