@@ -13,7 +13,6 @@
 # under the License.
 #
 
-import copy
 from cryptography import fernet
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -39,7 +38,7 @@ class BaseAmphoraTask(task.Task):
     """Base task to load drivers common to the tasks."""
 
     def __init__(self, **kwargs):
-        super(BaseAmphoraTask, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.amphora_driver = stevedore_driver.DriverManager(
             namespace='octavia.amphora.drivers',
             name=CONF.controller_worker.amphora_driver,
@@ -335,9 +334,8 @@ class AmphoraPostVIPPlug(BaseAmphoraTask):
             **amphorae_network_config[
                 amphora.get(constants.ID)][constants.VRRP_PORT])
         # Required for noop-case
-        vip_arg = copy.deepcopy(
-            amphorae_network_config[
-                amphora.get(constants.ID)][constants.VIP_SUBNET])
+        vip_arg = amphorae_network_config[amphora.get(
+            constants.ID)][constants.VIP_SUBNET]
         if vip_arg:
             host_routes = vip_arg.get('host_routes')
             if host_routes:
@@ -575,7 +573,7 @@ class AmphoraComputeConnectivityWait(BaseAmphoraTask):
 
 
 class AmphoraConfigUpdate(BaseAmphoraTask):
-    """Task to push a new amphora agent configuration to the amphroa."""
+    """Task to push a new amphora agent configuration to the amphora."""
 
     def execute(self, amphora, flavor):
         # Extract any flavor based settings
@@ -591,7 +589,7 @@ class AmphoraConfigUpdate(BaseAmphoraTask):
             amphora.get(constants.ID), topology)
         db_amp = self.amphora_repo.get(db_apis.get_session(),
                                        id=amphora[constants.ID])
-        # Push the new configuration to the amphroa
+        # Push the new configuration to the amphora
         try:
             self.amphora_driver.update_amphora_agent_config(db_amp,
                                                             agent_config)
