@@ -21,6 +21,7 @@ from sqlalchemy.ext import orderinglist
 from sqlalchemy import orm
 from sqlalchemy.orm import validates
 from sqlalchemy.sql import func
+from sqlalchemy_utils import ScalarListType
 
 from octavia.api.v2.types import amphora
 from octavia.api.v2.types import availability_zone_profile
@@ -174,6 +175,20 @@ class ListenerStatistics(base_models.BASE):
                                'Current value is %(value)d.') % data)
         return value
 
+    def __iadd__(self, other):
+        if isinstance(other, (ListenerStatistics,
+                              data_models.ListenerStatistics)):
+            self.bytes_in += other.bytes_in
+            self.bytes_out += other.bytes_out
+            self.request_errors += other.request_errors
+            self.total_connections += other.total_connections
+        else:
+            raise TypeError(  # noqa: O342
+                "unsupported operand type(s) for +=: '{0}' and '{1}'".format(
+                    type(self), type(other)))
+
+        return self
+
 
 class Member(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
              models.TimestampMixin, base_models.NameMixin,
@@ -337,6 +352,8 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
     crl_container_id = sa.Column(sa.String(255), nullable=True)
     tls_enabled = sa.Column(sa.Boolean, default=False, nullable=False)
     tls_ciphers = sa.Column(sa.String(2048), nullable=True)
+    tls_versions = sa.Column(ScalarListType(), nullable=True)
+    alpn_protocols = sa.Column(ScalarListType(), nullable=True)
 
     # This property should be a unique list of any listeners that reference
     # this pool as its default_pool and any listeners referenced by enabled
@@ -522,6 +539,8 @@ class Listener(base_models.BASE, base_models.IdMixin,
         nullable=False, default=constants.CLIENT_AUTH_NONE)
     client_crl_container_id = sa.Column(sa.String(255), nullable=True)
     tls_ciphers = sa.Column(sa.String(2048), nullable=True)
+    tls_versions = sa.Column(ScalarListType(), nullable=True)
+    alpn_protocols = sa.Column(ScalarListType(), nullable=True)
 
     _tags = orm.relationship(
         'Tags',
@@ -747,11 +766,15 @@ class Quotas(base_models.BASE):
     load_balancer = sa.Column(sa.Integer(), nullable=True)
     member = sa.Column(sa.Integer(), nullable=True)
     pool = sa.Column(sa.Integer(), nullable=True)
+    l7policy = sa.Column(sa.Integer(), nullable=True)
+    l7rule = sa.Column(sa.Integer(), nullable=True)
     in_use_health_monitor = sa.Column(sa.Integer(), nullable=True)
     in_use_listener = sa.Column(sa.Integer(), nullable=True)
     in_use_load_balancer = sa.Column(sa.Integer(), nullable=True)
     in_use_member = sa.Column(sa.Integer(), nullable=True)
     in_use_pool = sa.Column(sa.Integer(), nullable=True)
+    in_use_l7policy = sa.Column(sa.Integer(), nullable=True)
+    in_use_l7rule = sa.Column(sa.Integer(), nullable=True)
 
 
 class FlavorProfile(base_models.BASE, base_models.IdMixin,
