@@ -152,7 +152,6 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
             security_group_id=sec_grp_id)
 
         updated_ports = []
-        listener_peer_ports = []
         for listener in load_balancer.listeners:
             if (listener.provisioning_status in [constants.PENDING_DELETE,
                                                  constants.DELETED]):
@@ -172,17 +171,11 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
                 port = (listener.protocol_port, protocol, None)
                 updated_ports.append(port)
 
-            listener_peer_ports.append(listener.peer_port)
-
-        # As the peer port will hold the tcp connection for keepalived and
-        # haproxy session synchronization, so here the security group rule
-        # should be just related with tcp protocol only. To avoid adding
-        # duplicate rules, peer_port info should be added if updated_ports
-        # does not have the peer_port entry with allowed_cidr 0.0.0.0/0
-        tcp_lower = constants.PROTOCOL_TCP.lower()
-        for peer_port in listener_peer_ports:
-            if (peer_port, tcp_lower, "0.0.0.0/0") not in updated_ports:
-                updated_ports.append((peer_port, tcp_lower, None))
+            # As the peer port will hold the tcp connection for keepalived and
+            # haproxy session synchronization, so here the security group rule
+            # should be just related with tcp protocol only.
+            updated_ports.append(
+                (listener.peer_port, constants.PROTOCOL_TCP.lower(), None))
 
         # Just going to use port_range_max for now because we can assume that
         # port_range_max and min will be the same since this driver is
@@ -204,7 +197,9 @@ class AllowedAddressPairsDriver(neutron_base.BaseNeutronDriver):
         del_ports = set(old_ports) - set(updated_ports)
         for rule in rules.get('security_group_rules', []):
             if (rule.get('protocol', '') and
-                    rule.get('protocol', '').lower() in ['tcp', 'udp'] and
+                    rule.get('protocol', '').upper() in
+                    [constants.PROTOCOL_TCP, constants.PROTOCOL_UDP,
+                     lib_consts.PROTOCOL_SCTP] and
                     (rule.get('port_range_max'), rule.get('protocol'),
                      rule.get('remote_ip_prefix')) in del_ports):
                 rule_id = rule.get(constants.ID)
