@@ -12,10 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 #
-
 import copy
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 
@@ -27,7 +26,7 @@ import octavia.tests.unit.base as base
 class TestVRRPRestDriver(base.TestCase):
 
     def setUp(self):
-        super(TestVRRPRestDriver, self).setUp()
+        super().setUp()
         conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
         conf.config(group="haproxy_amphora", base_path='/tmp/test')
         conf.config(group="keepalived_vrrp", vrrp_garp_refresh_interval=5)
