@@ -15,6 +15,7 @@
 
 import collections
 
+from octavia_lib.common import constants as lib_consts
 from oslo_config import cfg
 
 from octavia.common import constants
@@ -416,16 +417,6 @@ RET_UDP_HEALTH_MONITOR = {
                           '/lvs/check/udp_check.sh')
 }
 
-UDP_HEALTH_MONITOR_NO_SCRIPT = {
-    'id': 'sample_monitor_id_1',
-    'check_script_path': None,
-    'delay': 30,
-    'enabled': True,
-    'fall_threshold': 3,
-    'timeout': 31,
-    'type': 'UDP'
-}
-
 RET_UDP_MEMBER = {
     'id': 'member_id_1',
     'address': '192.0.2.10',
@@ -469,8 +460,8 @@ UDP_MEMBER_2 = {
 RET_UDP_POOL = {
     'id': 'sample_pool_id_1',
     'enabled': True,
-    'health_monitor': UDP_HEALTH_MONITOR_NO_SCRIPT,
-    'lb_algorithm': 'wrr',
+    'health_monitor': RET_UDP_HEALTH_MONITOR,
+    'lb_algorithm': 'rr',
     'members': [UDP_MEMBER_1, UDP_MEMBER_2],
     'protocol': 'udp',
     'session_persistence': UDP_SOURCE_IP_BODY
@@ -482,7 +473,7 @@ RET_UDP_LISTENER = {
         'id': 'sample_pool_id_1',
         'enabled': True,
         'health_monitor': RET_UDP_HEALTH_MONITOR,
-        'lb_algorithm': 'wrr',
+        'lb_algorithm': 'rr',
         'members': [UDP_MEMBER_1, UDP_MEMBER_2],
         'protocol': 'udp',
         'session_persistence': UDP_SOURCE_IP_BODY
@@ -493,22 +484,103 @@ RET_UDP_LISTENER = {
     'protocol_port': '80'
 }
 
+SCTP_SOURCE_IP_BODY = {
+    'type': constants.SESSION_PERSISTENCE_SOURCE_IP,
+    'persistence_timeout': 33,
+    'persistence_granularity': '255.0.0.0'
+}
+
+RET_SCTP_HEALTH_MONITOR = {
+    'id': 'sample_monitor_id_1',
+    'type': lib_consts.HEALTH_MONITOR_SCTP,
+    'delay': 30,
+    'timeout': 31,
+    'enabled': True,
+    'fall_threshold': 3,
+    'check_script_path': 'amphora-health-checker sctp'
+}
+
+RET_SCTP_MEMBER = {
+    'id': 'member_id_1',
+    'address': '192.0.2.10',
+    'protocol_port': 82,
+    'weight': 13,
+    'enabled': True,
+    'monitor_address': None,
+    'monitor_port': None
+}
+
+RET_SCTP_MEMBER_MONITOR_IP_PORT = {
+    'id': 'member_id_1',
+    'address': '192.0.2.10',
+    'protocol_port': 82,
+    'weight': 13,
+    'enabled': True,
+    'monitor_address': '192.168.1.1',
+    'monitor_port': 9000
+}
+
+SCTP_MEMBER_1 = {
+    'id': 'sample_member_id_1',
+    'address': '10.0.0.99',
+    'enabled': True,
+    'protocol_port': 82,
+    'weight': 13,
+    'monitor_address': None,
+    'monitor_port': None,
+}
+
+SCTP_MEMBER_2 = {
+    'id': 'sample_member_id_2',
+    'address': '10.0.0.98',
+    'enabled': True,
+    'protocol_port': 82,
+    'weight': 13,
+    'monitor_address': None,
+    'monitor_port': None
+}
+
+RET_SCTP_POOL = {
+    'id': 'sample_pool_id_1',
+    'enabled': True,
+    'health_monitor': RET_SCTP_HEALTH_MONITOR,
+    'lb_algorithm': 'rr',
+    'members': [SCTP_MEMBER_1, SCTP_MEMBER_2],
+    'protocol': 'sctp',
+    'session_persistence': SCTP_SOURCE_IP_BODY
+}
+
+RET_SCTP_LISTENER = {
+    'connection_limit': 98,
+    'default_pool': {
+        'id': 'sample_pool_id_1',
+        'enabled': True,
+        'health_monitor': RET_SCTP_HEALTH_MONITOR,
+        'lb_algorithm': 'rr',
+        'members': [SCTP_MEMBER_1, SCTP_MEMBER_2],
+        'protocol': 'sctp',
+        'session_persistence': SCTP_SOURCE_IP_BODY
+    },
+    'enabled': True,
+    'id': 'sample_listener_id_1',
+    'protocol_mode': 'sctp',
+    'protocol_port': '80'
+}
+
 
 def sample_listener_loadbalancer_tuple(
-        proto=None, topology=None, enabled=True, pools=None):
-    proto = 'HTTP' if proto is None else proto
+        topology=None, enabled=True, pools=None):
     if topology and topology in ['ACTIVE_STANDBY', 'ACTIVE_ACTIVE']:
         more_amp = True
     else:
         more_amp = False
         topology = constants.TOPOLOGY_SINGLE
     in_lb = collections.namedtuple(
-        'load_balancer', 'id, name, protocol, vip, amphorae, topology, '
+        'load_balancer', 'id, name, vip, amphorae, topology, '
         'pools, listeners, enabled, project_id')
     return in_lb(
         id='sample_loadbalancer_id_1',
         name='test-lb',
-        protocol=proto,
         vip=sample_vip_tuple(),
         amphorae=[sample_amphora_tuple(role=constants.ROLE_MASTER),
                   sample_amphora_tuple(
@@ -526,8 +598,7 @@ def sample_listener_loadbalancer_tuple(
 
 
 def sample_lb_with_udp_listener_tuple(
-        proto=None, topology=None, enabled=True, pools=None):
-    proto = 'HTTP' if proto is None else proto
+        topology=None, enabled=True, pools=None):
     if topology and topology in ['ACTIVE_STANDBY', 'ACTIVE_ACTIVE']:
         more_amp = True
     else:
@@ -541,12 +612,11 @@ def sample_lb_with_udp_listener_tuple(
         monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT)]
 
     in_lb = collections.namedtuple(
-        'load_balancer', 'id, name, protocol, vip, amphorae, topology, '
+        'load_balancer', 'id, name, vip, amphorae, topology, '
         'pools, enabled, project_id, listeners')
     return in_lb(
         id='sample_loadbalancer_id_1',
         name='test-lb',
-        protocol=proto,
         vip=sample_vip_tuple(),
         amphorae=[sample_amphora_tuple(role=constants.ROLE_MASTER),
                   sample_amphora_tuple(
@@ -611,7 +681,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           alpn_protocols=constants.
                           AMPHORA_SUPPORTED_ALPN_PROTOCOLS,
                           sample_default_pool=1,
-                          pool_enabled=True):
+                          pool_enabled=True,
+                          backend_alpn_protocols=constants.
+                          AMPHORA_SUPPORTED_ALPN_PROTOCOLS):
     proto = 'HTTP' if proto is None else proto
     if be_proto is None:
         be_proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
@@ -649,7 +721,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
                 tls_versions=backend_tls_versions,
-                enabled=pool_enabled),
+                enabled=pool_enabled,
+                alpn_protocols=backend_alpn_protocols),
             sample_pool_tuple(
                 proto=be_proto, monitor=monitor, persistence=persistence,
                 persistence_type=persistence_type,
@@ -661,7 +734,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
                 tls_versions=None,
-                enabled=pool_enabled)]
+                enabled=pool_enabled,
+                alpn_protocols=backend_alpn_protocols)]
         l7policies = [
             sample_l7policy_tuple('sample_l7policy_id_1', sample_policy=1),
             sample_l7policy_tuple('sample_l7policy_id_2', sample_policy=2),
@@ -687,7 +761,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 listener_id='sample_listener_id_1',
                 tls_ciphers=backend_tls_ciphers,
                 tls_versions=backend_tls_versions,
-                enabled=pool_enabled)]
+                enabled=pool_enabled,
+                alpn_protocols=backend_alpn_protocols)]
         l7policies = []
     listener = in_listener(
         id=id,
@@ -695,7 +770,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
         protocol_port=port,
         protocol=proto,
         load_balancer=sample_listener_loadbalancer_tuple(
-            proto=proto, topology=topology, pools=pools),
+            topology=topology, pools=pools),
         peer_port=peer_port,
         default_pool=sample_pool_tuple(
             listener_id='sample_listener_id_1',
@@ -803,20 +878,27 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                       tls_ciphers=constants.CIPHERS_OWASP_SUITE_B,
                       tls_versions=constants.TLS_VERSIONS_OWASP_SUITE_B,
                       lb_algorithm=constants.LB_ALGORITHM_ROUND_ROBIN,
-                      enabled=True):
+                      enabled=True,
+                      alpn_protocols=constants.
+                      AMPHORA_SUPPORTED_ALPN_PROTOCOLS):
     proto = 'HTTP' if proto is None else proto
     if not tls_enabled:
         tls_ciphers = None
         tls_versions = None
-    monitor_proto = proto if monitor_proto is None else monitor_proto
+        alpn_protocols = None
+    if monitor_proto is None:
+        if proto == constants.PROTOCOL_UDP:
+            monitor_proto = constants.HEALTH_MONITOR_UDP_CONNECT
+        else:
+            monitor_proto = proto
     in_pool = collections.namedtuple(
         'pool', 'id, protocol, lb_algorithm, members, health_monitor, '
                 'session_persistence, enabled, operating_status, '
                 'tls_certificate_id, ca_tls_certificate_id, '
                 'crl_container_id, tls_enabled, tls_ciphers, '
-                'tls_versions, provisioning_status, ' +
+                'tls_versions, provisioning_status, alpn_protocols, ' +
                 constants.HTTP_REUSE)
-    if (proto == constants.PROTOCOL_UDP and
+    if (proto in constants.LVS_PROTOCOLS and
             persistence_type == constants.SESSION_PERSISTENCE_SOURCE_IP):
         kwargs = {'persistence_type': persistence_type,
                   'persistence_timeout': persistence_timeout,
@@ -871,7 +953,8 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         tls_enabled=tls_enabled,
         tls_ciphers=tls_ciphers,
         tls_versions=tls_versions,
-        provisioning_status=provisioning_status)
+        provisioning_status=provisioning_status,
+        alpn_protocols=alpn_protocols)
 
 
 def sample_member_tuple(id, ip, enabled=True, operating_status='ACTIVE',
@@ -951,6 +1034,8 @@ def sample_health_monitor_tuple(proto='HTTP', sample_hm=1,
     if proto == constants.HEALTH_MONITOR_UDP_CONNECT:
         kwargs['check_script_path'] = (CONF.haproxy_amphora.base_path +
                                        'lvs/check/' + 'udp_check.sh')
+    elif proto == lib_consts.HEALTH_MONITOR_SCTP:
+        kwargs['check_script_path'] = 'amphora-health-checker sctp'
     else:
         kwargs['check_script_path'] = None
     return monitor(**kwargs)
