@@ -557,7 +557,10 @@ class TestAmphoraDriverTasks(base.TestCase):
             _session_mock,
             id=AMP_ID,
             status=constants.ERROR)
-        repo.LoadBalancerRepository.update.assert_not_called()
+        repo.LoadBalancerRepository.update.assert_called_once_with(
+            _session_mock,
+            id=LB_ID,
+            provisioning_status=constants.ERROR)
 
         self.assertIsNone(amp)
 
@@ -571,7 +574,10 @@ class TestAmphoraDriverTasks(base.TestCase):
             _session_mock,
             id=AMP_ID,
             status=constants.ERROR)
-        repo.LoadBalancerRepository.update.assert_not_called()
+        repo.LoadBalancerRepository.update.assert_called_once_with(
+            _session_mock,
+            id=LB_ID,
+            provisioning_status=constants.ERROR)
 
         self.assertIsNone(amp)
 
@@ -624,11 +630,6 @@ class TestAmphoraDriverTasks(base.TestCase):
             self.assertEqual(hr1['destination'], hr2.destination)
             self.assertEqual(hr1['nexthop'], hr2.nexthop)
 
-        self.assertEqual(
-            host_routes,
-            amphorae_net_config_mock[AMP_ID][
-                constants.VIP_SUBNET]['host_routes'])
-
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.get')
     def test_amphorae_post_vip_plug(self, mock_lb_get,
@@ -658,6 +659,33 @@ class TestAmphoraDriverTasks(base.TestCase):
             _db_amphora_mock, _db_load_balancer_mock, amphorae_net_config_mock,
             vip_subnet=vip_subnet, vrrp_port=vrrp_port)
 
+        # Test revert
+        amp = amphora_post_vip_plug_obj.revert(None, _LB_mock)
+        repo.LoadBalancerRepository.update.assert_called_once_with(
+            _session_mock,
+            id=LB_ID,
+            provisioning_status=constants.ERROR)
+
+        self.assertIsNone(amp)
+
+        # Test revert with exception
+        repo.LoadBalancerRepository.update.reset_mock()
+        mock_loadbalancer_repo_update.side_effect = Exception('fail')
+        amp = amphora_post_vip_plug_obj.revert(None, _LB_mock)
+        repo.LoadBalancerRepository.update.assert_called_once_with(
+            _session_mock,
+            id=LB_ID,
+            provisioning_status=constants.ERROR)
+
+        self.assertIsNone(amp)
+
+        # Test revert when this task failed
+        repo.AmphoraRepository.update.reset_mock()
+        amp = amphora_post_vip_plug_obj.revert(
+            failure.Failure.from_exception(Exception('boom')), _amphora_mock,
+            None)
+        repo.AmphoraRepository.update.assert_not_called()
+
     def test_amphora_cert_upload(self,
                                  mock_driver,
                                  mock_generate_uuid,
